Django Replay
=============

Django Replay is an Apache2 licensed Python module that records and replays web
requests.

Features
--------

- Pure-Python (easy to hack with)
- Developed on Python 2.7
- Tested on CPython 2.7

Quickstart
----------

Installing Django Replay is simple with
`pip <http://www.pip-installer.org/>`_::

  $ pip install django-replay

.. todo: Describe django app installation steps.

Tutorial
--------

.. todo: Describe workflow.

Reference and Indices
---------------------

* `Django Replay Documentation`_
* `Django Replay at PyPI`_
* `Django Replay at GitHub`_
* `Django Replay Issue Tracker`_

.. _`Django Replay Documentation`: http://www.grantjenks.com/docs/django-replay/
.. _`Django Replay at PyPI`: https://pypi.python.org/pypi/django-replay/
.. _`Django Replay at GitHub`: https://github.com/grantjenks/django-replay/
.. _`Django Replay Issue Tracker`: https://github.com/grantjenks/django-replay/issues/

License
-------

Copyright 2017 Grant Jenks

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
